pub struct ComputedCenterOfMass(pub Vector);Expand description
The local center of mass computed for a dynamic rigid body, taking into account colliders and descendants. Represents the average position of mass in the body.
The total center of mass is computed as the weighted average of the centers of mass
of all attached colliders and the center of mass of the rigid body entity itself.
The center of mass of an entity is determined by its CenterOfMass component,
or if it is not present, from an attached Collider based on its shape.
Related Types
CenterOfMasscan be used to set the local center of mass associated with an individual entity.ComputedMassstores the total mass of a rigid body, taking into account colliders and descendants.ComputedAngularInertiastores the total angular inertia of a rigid body, taking into account colliders and descendants.MassPropertyHelperis aSystemParamwith utilities for computing and updating mass properties.
Tuple Fields
0: VectorImplementations
Methods from Deref<Target = Vector>
pub const ZERO: Vec3
pub const ONE: Vec3
pub const NEG_ONE: Vec3
pub const MIN: Vec3
pub const MAX: Vec3
pub const NAN: Vec3
pub const INFINITY: Vec3
pub const NEG_INFINITY: Vec3
pub const X: Vec3
pub const Y: Vec3
pub const Z: Vec3
pub const NEG_X: Vec3
pub const NEG_Y: Vec3
pub const NEG_Z: Vec3
pub const AXES: [Vec3; 3]
pub const USES_CORE_SIMD: bool = false
pub const USES_NEON: bool = false
pub const USES_SCALAR_MATH: bool = true
pub const USES_SSE2: bool = false
pub const USES_WASM_SIMD: bool = false
pub const USES_WASM32_SIMD: bool = false